@@ -338,8 +338,9 @@ def make_unit_parser(units_path=None, dicts=None):
 
     _hmsret = lambda v: param('quantity')(JOINT(RETURN(hms(*v)),
                                                 param('unit')(RETURN((('quote', 'seconds'),)))))
-    duration_hms = BIND(JOINT(SKIP(int_, colon), SKIP(int_, colon), int_, join=False), _hmsret)
-    dilution_factor = param('dilution')(JOINT(SKIP(int_, colon), int_, join=False))
+    duration_hms = BIND(JOINT(SKIP(int_, colon), SKIP(int_, colon), int_, join=False), _hmsret)  # FIXME loss of repr
+    #duration_hm = BIND(JOINT(SKIP(int_, colon), int_, join=False), _hmsret)  # TODO FIXME loss of repr
+    ratio = param('ratio')(JOINT(SKIP(int_, colon), int_, join=False))  # dilution starts with 1 but is an aspect
     sq = COMPOSE(spaces, quantity)
     sby = COMPOSE(spaces, by)
     dimensions = param('dimensions')(BIND(JOINT(quantity_with_unit,
@@ -374,12 +375,15 @@ def make_unit_parser(units_path=None, dicts=None):
     #def approximate_thing(thing): return JOINT(EXACTLY_ONE(approx), COMPOSE(spaces, thing), join=False)
 
     def FAILURE(p):
-        return param('parse-failure')(lambda null: (True, tuple(), p))(p)
+        # NOTE we do not return (True, (p,), p) because FAILURE
+        # should only be used in the last slot, nothing should be
+        # parsing after this in the same chain
+        return param('parse-failure')(lambda null: (True, (p,), ''))(p)
 
     # TODO objective specifications...
     components = OR(dimensions,
-                    duration_hms,  # must come first otherwise dilution will always match first
-                    dilution_factor,
+                    duration_hms,  # must come first otherwise ratio will always match first
+                    ratio,
                     expression,
                     quantity,
                     boo,
@@ -431,7 +435,7 @@ def parse_for_tests(parameter_expression=None):
               '3*10^6 infectious particles/mL',
               '4.7 +- 0.6 x 10^7 / mm^3',  # FIXME this is ambigious? YES VERY also unit dimensionality...
               '1,850', '4C', 'three', 'Four', 'P28.5±2 days',
-              '12-V', '10-mL', '+1',
+              '12-V', '10-mL', '+1', 'Forty seconds'
              )
     should_fail = ('~~~~1',
                    "(pH 7.3",
